@@ -57,6 +57,8 @@ REPO_ROOT = Path(__file__).absolute().parent.parent.parent
 TEST_RESOURCES_DIR = os.path.join(REPO_ROOT, "tests", "test_chaiverse", "resources")
 UNIT_TEST_MODEL_DIR = os.path.join(TEST_RESOURCES_DIR, "llama2-0b-unit-test")
 
+DEFAULT_CLUSTER_NAME = "kchai-coreweave-us-east-04"
+
 
 # TODO: Implement user roles in guanaco_auth to avoid this
 INTERNAL_USERS = [
@@ -67,21 +69,14 @@ INTERNAL_USERS = [
     "alexdaoud",
     "zonemercy",
     "chai_tester",
-    "albert_chai",
     "chaiwill",
-    "azuruce",
     "robert_irvine",
     "chaiversetests",
-    "valentin",
     "Jellywibble",
-    "valentin87",
     "rirv938",
-    "ebony59",
-    "jxlu90",
     "NischayDnk",
-    "dtnewman",
     "richhx",
-    "bogoconic1",
+    "fanghan0520"
 ]
 
 
