@@ -8,7 +8,7 @@ from pydantic import BaseModel, Extra, Field, PrivateAttr, validator, field_vali
 
 
 from chaiverse import config, errors, formatters, utils
-from chaiverse.config import LEADERBOARD_ENDPOINT
+from chaiverse.config import DEFAULT_CLUSTER_NAME, LEADERBOARD_ENDPOINT
 from chaiverse.cli_utils.login_cli import auto_authenticate
 from chaiverse.http_client import SubmitterClient
 from chaiverse.lib.dict_tools import deep_get
@@ -197,14 +197,21 @@ class FrontEndSubmissionRequest(BaseModel):
         exclude=True,
         default=True,
         options={
-            "hidden": True
+            "hidden": True,
         },
     )
 
     platform: Optional[str] = Field(
         default="coreweave/mkml",
         options={
-            "hidden": True
+            "hidden": True,
+        },
+    )
+
+    cluster_name: Optional[str] = Field(
+        default=DEFAULT_CLUSTER_NAME,
+        options={
+            "hidden": True,
         },
     )
 
